DocumentParameter class

Document parameter for template headers.

Inheritance
Annotations

Constructors

DocumentParameter({required String documentUrl, String? filename})
Creates a new document parameter.
const

Properties

documentUrl → String
URL of the document
final
filename → String?
Optional filename to display
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ParameterType
Type of the parameter
finalinherited

Methods

isValid() → bool
Validates the parameter.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the parameter to a JSON-serializable map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited