TokenStorage class abstract

Abstract interface for token storage implementations.

Implementers

Constructors

TokenStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteToken() → Future<void>
Deletes a token from persistent storage.
getToken() → Future<String?>
Retrieves a token from persistent storage.
hasToken() → Future<bool>
Checks if a token exists in persistent storage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveToken(String token) → Future<void>
Saves a token to persistent storage.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited